@@ -66,7 +66,8 @@ void xmlAddDtdEntity(xmlDocPtr doc, const CHAR *name, int type,
 xmlEntityPtr xmlGetPredefinedEntity(const CHAR *name);
 xmlEntityPtr xmlGetDocEntity(xmlDocPtr doc, const CHAR *name);
 xmlEntityPtr xmlGetDtdEntity(xmlDocPtr doc, const CHAR *name);
-CHAR *xmlEncodeEntities(xmlDocPtr doc, const CHAR *input);
+const CHAR *xmlEncodeEntities(xmlDocPtr doc, const CHAR *input);
+CHAR *xmlEncodeEntitiesReentrant(xmlDocPtr doc, const CHAR *input);
 xmlEntitiesTablePtr xmlCreateEntitiesTable(void);
 xmlEntitiesTablePtr xmlCopyEntitiesTable(xmlEntitiesTablePtr table);
 void xmlFreeEntitiesTable(xmlEntitiesTablePtr table);
