@@ -12,7 +12,7 @@
 
 /**
  * xmlParserError:
- * @ctxt:  an XML parser context
+ * @ctx:  an XML parser context
  * @msg:  the message to display/transmit
  * @...:  extra parameters for the message display
  * 
@@ -20,8 +20,9 @@
  * extra parameters.
  */
 void
-xmlParserError(xmlParserCtxtPtr ctxt, const char *msg, ...)
+xmlParserError(void *ctx, const char *msg, ...)
 {
+    xmlParserCtxtPtr ctxt = (xmlParserCtxtPtr) ctx;
     const CHAR *cur, *base;
     va_list args;
     int n;
@@ -35,15 +36,14 @@ xmlParserError(xmlParserCtxtPtr ctxt, const char *msg, ...)
         
     fprintf(stderr, "error: ");
     vfprintf(stderr, msg, args);
-    va_end(ap);
+    va_end(args);
     cur = ctxt->input->cur;
     base = ctxt->input->base;
     while ((cur > base) && ((*cur == '\n') || (*cur == '\r'))) {
 	cur--;
-	base--;
     }
     n = 0;
-    while ((n++ < 60) && (cur > base) && (*cur != '\n') && (*cur != '\r'))
+    while ((n++ < 80) && (cur > base) && (*cur != '\n') && (*cur != '\r'))
         cur--;
     if ((*cur == '\n') || (*cur == '\r')) cur++;
     base = cur;
@@ -57,7 +57,7 @@ xmlParserError(xmlParserCtxtPtr ctxt, const char *msg, ...)
     while ((*cur == '\n') || (*cur == '\r'))
 	cur--;
     n = 0;
-    while ((cur != base) && (n++ < 60)) {
+    while ((cur != base) && (n++ < 80)) {
         fprintf(stderr, " ");
         base++;
     }
@@ -66,7 +66,7 @@ xmlParserError(xmlParserCtxtPtr ctxt, const char *msg, ...)
 
 /**
  * xmlParserWarning:
- * @ctxt:  an XML parser context
+ * @ctx:  an XML parser context
  * @msg:  the message to display/transmit
  * @...:  extra parameters for the message display
  * 
@@ -74,8 +74,9 @@ xmlParserError(xmlParserCtxtPtr ctxt, const char *msg, ...)
  * extra parameters.
  */
 void
-xmlParserWarning(xmlParserCtxtPtr ctxt, const char *msg, ...)
+xmlParserWarning(void *ctx, const char *msg, ...)
 {
+    xmlParserCtxtPtr ctxt = (xmlParserCtxtPtr) ctx;
     const CHAR *cur, *base;
     va_list args;
     int n;
@@ -89,13 +90,16 @@ xmlParserWarning(xmlParserCtxtPtr ctxt, const char *msg, ...)
         
     fprintf(stderr, "warning: ");
     vfprintf(stderr, msg, args);
-    va_end(ap);
+    va_end(args);
     cur = ctxt->input->cur;
     base = ctxt->input->base;
+    while ((cur > base) && ((*cur == '\n') || (*cur == '\r'))) {
+	cur--;
+    }
     n = 0;
-    while ((n++ < 60) && (cur > base) && (*cur != '\n') && (*cur != '\r'))
+    while ((n++ < 80) && (cur > base) && (*cur != '\n') && (*cur != '\r'))
         cur--;
-    if ((*cur != '\n') || (*cur != '\r')) cur++;
+    if ((*cur == '\n') || (*cur == '\r')) cur++;
     base = cur;
     n = 0;
     while ((*cur != 0) && (*cur != '\n') && (*cur != '\r') && (n < 79)) {
@@ -104,8 +108,10 @@ xmlParserWarning(xmlParserCtxtPtr ctxt, const char *msg, ...)
     }
     fprintf(stderr, "\n");
     cur = ctxt->input->cur;
+    while ((*cur == '\n') || (*cur == '\r'))
+	cur--;
     n = 0;
-    while ((cur != base) && (n++ < 60)) {
+    while ((cur != base) && (n++ < 80)) {
         fprintf(stderr, " ");
         base++;
     }
