@@ -62,6 +62,7 @@ typedef struct _xmlParserCtxt {
     const CHAR     *version;	      /* the XML version string */
     const CHAR     *encoding;         /* encoding, if any */
     int             standalone;       /* standalone document */
+    int                   html;       /* are we parsing an HTML document */
 
     /* Input stream stack */
     xmlParserInputPtr  input;         /* Current input stream */
@@ -179,6 +180,7 @@ extern const char *xmlParserVersion;
 
 extern xmlSAXLocator xmlDefaultSAXLocator;
 extern xmlSAXHandler xmlDefaultSAXHandler;
+extern xmlSAXHandler htmlDefaultSAXHandler;
 
 #include "entities.h"
 #include "xml-error.h"
@@ -188,7 +190,9 @@ extern xmlSAXHandler xmlDefaultSAXHandler;
  */
 CHAR *xmlStrdup(const CHAR *cur);
 CHAR *xmlStrndup(const CHAR *cur, int len);
-CHAR *xmlStrchr(const CHAR *str, CHAR val);
+CHAR *xmlStrsub(const CHAR *str, int start, int len);
+const CHAR *xmlStrchr(const CHAR *str, CHAR val);
+const CHAR *xmlStrstr(const CHAR *str, CHAR *val);
 int xmlStrcmp(const CHAR *str1, const CHAR *str2);
 int xmlStrncmp(const CHAR *str1, const CHAR *str2, int len);
 int xmlStrlen(const CHAR *str);
@@ -237,6 +241,7 @@ void xmlParserAddNodeInfo(xmlParserCtxtPtr ctxt,
                           const xmlParserNodeInfo* info);
 
 void xmlDefaultSAXHandlerInit(void);
+void htmlDefaultSAXHandlerInit(void);
 #ifdef __cplusplus
 }
 #endif
