@@ -676,7 +676,7 @@ xmlNodeListGetString(xmlDocPtr doc, xmlNodePtr list, int inLine) {
 	    else {
 	        CHAR *buffer;
 
-		buffer = xmlEncodeEntities(doc, node->content);
+		buffer = xmlEncodeEntitiesReentrant(doc, node->content);
 		if (buffer != NULL) {
 		    ret = xmlStrcat(ret, buffer);
 		    free(buffer);
@@ -2576,7 +2576,7 @@ xmlNodeDump(xmlBufferPtr buf, xmlDocPtr doc, xmlNodePtr cur, int level) {
 	if (cur->content != NULL) {
             CHAR *buffer;
 
-            buffer = xmlEncodeEntities(doc, cur->content);
+            buffer = xmlEncodeEntitiesReentrant(doc, cur->content);
 	    if (buffer != NULL) {
 		xmlBufferWriteCHAR(buf, buffer);
 		free(buffer);
@@ -2619,8 +2619,15 @@ xmlNodeDump(xmlBufferPtr buf, xmlDocPtr doc, xmlNodePtr cur, int level) {
 	return;
     }
     xmlBufferWriteChar(buf, ">");
-    if (cur->content != NULL)
-	xmlBufferWriteCHAR(buf, xmlEncodeEntities(doc, cur->content));
+    if (cur->content != NULL) {
+	CHAR *buffer;
+
+	buffer = xmlEncodeEntitiesReentrant(doc, cur->content);
+	if (buffer != NULL) {
+	    xmlBufferWriteCHAR(buf, buffer);
+	    free(buffer);
+	}
+    }
     if (cur->childs != NULL) {
 	xmlNodeListDump(buf, doc, cur->childs, level + 1);
     }
@@ -2643,11 +2650,11 @@ xmlNodeDump(xmlBufferPtr buf, xmlDocPtr doc, xmlNodePtr cur, int level) {
  */
 static void
 xmlDocContentDump(xmlBufferPtr buf, xmlDocPtr cur) {
-    if (oldXMLWDcompatibility)
-	xmlBufferWriteChar(buf, "<?XML version=");
-    else 
-	xmlBufferWriteChar(buf, "<?xml version=");
-    xmlBufferWriteQuotedString(buf, cur->version);
+    xmlBufferWriteChar(buf, "<?xml version=");
+    if (cur->version != NULL) 
+	xmlBufferWriteQuotedString(buf, cur->version);
+    else
+	xmlBufferWriteChar(buf, "\"1.0\"");
     if (cur->encoding != NULL) {
         xmlBufferWriteChar(buf, " encoding=");
 	xmlBufferWriteQuotedString(buf, cur->encoding);
